PyXMake Developer Guide: PyXMake.VTL.java Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.java Namespace Reference

## Functions
| main (BuildID, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(1), libs=VTL.GetLinkDependency(0, 1, __arch), source=os.path.join(__mcd_core_path,"src"), include=[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)], dependency=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), output=os.path.join(__mcd_core_path,"bin", Utility.GetPlatform(), __arch), architecture=__arch, scratch=VTL.Scratch, verbosity=2)

## Variables
| parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")
| metavar
| nargs
| help
| _ = sys.argv[1]
| args
| make_opt = args.make[0]
str | BuildID = 'bbeam_java';
| files
| source
| include
| dependency
| libs

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile the BoxBeam & MCODAC for Java applications
                 using Intel Fortran and Java Native Access (JNA)
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.java.main | ( |  | BuildID,
|  |  | files = VTL.GetSourceCode(0),
|  |  | command = VTL.GetBuildCommand(1),
|  |  | libs = VTL.GetLinkDependency(0, 1, __arch),
|  |  | source = os.path.join(__mcd_core_path,"src"),
|  |  | include = [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)],
|  |  | dependency = os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch),
|  |  | output = os.path.join(__mcd_core_path,"bin",Utility.GetPlatform(),__arch),
|  |  | architecture = __arch,
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2 )

    Main function to execute the script.

Definition at line 53 of file java.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.java._ = sys.argv[1]
| protected

Definition at line 92 of file java.py.

## ◆ args

PyXMake.VTL.java.args

Definition at line 93 of file java.py.

## ◆ BuildID

str PyXMake.VTL.java.BuildID = 'bbeam_java';

Definition at line 103 of file java.py.

## ◆ dependency

PyXMake.VTL.java.dependency

Definition at line 105 of file java.py.

## ◆ files

PyXMake.VTL.java.files

Definition at line 104 of file java.py.

## ◆ help

PyXMake.VTL.java.help

Definition at line 85 of file java.py.

## ◆ include

PyXMake.VTL.java.include

Definition at line 105 of file java.py.

## ◆ libs

PyXMake.VTL.java.libs

Definition at line 105 of file java.py.

## ◆ make_opt

int PyXMake.VTL.java.make_opt = args.make[0]

Definition at line 95 of file java.py.

## ◆ metavar

PyXMake.VTL.java.metavar

Definition at line 85 of file java.py.

## ◆ nargs

PyXMake.VTL.java.nargs

Definition at line 85 of file java.py.

## ◆ parser

PyXMake.VTL.java.parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")

Definition at line 84 of file java.py.

## ◆ source

PyXMake.VTL.java.source

Definition at line 104 of file java.py.